summaryrefslogtreecommitdiffstats
path: root/kjsembed/jseventmapper.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jseventmapper.h')
-rw-r--r--kjsembed/jseventmapper.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kjsembed/jseventmapper.h b/kjsembed/jseventmapper.h
index cdcb4630..3539e94a 100644
--- a/kjsembed/jseventmapper.h
+++ b/kjsembed/jseventmapper.h
@@ -22,9 +22,9 @@
#ifndef JSEVENTMAPPER_H
#define JSEVENTMAPPER_H
-#include <qdict.h>
-#include <qevent.h>
-#include <qintdict.h>
+#include <tqdict.h>
+#include <tqevent.h>
+#include <tqintdict.h>
#include <kjs/identifier.h>
#include <kjsembed/jsbinding.h>
@@ -32,7 +32,7 @@
namespace KJSEmbed {
/**
* Maintains a map between the types of QEvent and the names of their event
* handlers.
*
* @author Richard Moore, rich@kde.org
@@ -47,7 +47,7 @@ public:
* Adds an event to the map. The event handler has the specified name, and
* the event has the specified type.
*/
- void addEvent( const KJS::Identifier &name, QEvent::Type t );
+ void addEvent( const KJS::Identifier &name, TQEvent::Type t );
/** Returns true iff the specified name is the identifier for an event handler. */
bool isEventHandler( const KJS::Identifier &name ) const {
@@ -55,13 +55,13 @@ public:
}
/** Returns the type of the events handled by the specified handler. */
- QEvent::Type findEventType( const KJS::Identifier &name ) const;
+ TQEvent::Type findEventType( const KJS::Identifier &name ) const;
- KJS::Identifier *findEventHandler( QEvent::Type t ) const { return eventToHandler.find(t); }
+ KJS::Identifier *findEventHandler( TQEvent::Type t ) const { return eventToHandler.find(t); }
private:
- QDict<uint> handlerToEvent;
- QIntDict<KJS::Identifier> eventToHandler;
+ TQDict<uint> handlerToEvent;
+ TQIntDict<KJS::Identifier> eventToHandler;
class JSEventMapperPrivate *d;
};
@@ -32,7 +32,7 @@
namespace KJSEmbed {
/**
- * Maintains a map between the types of QEvent and the names of their event
+ * Maintains a map between the types of TQEvent and the names of their event
* handlers.
*